summaryrefslogtreecommitdiffstats
path: root/chrome/app/breakpad_linux.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/app/breakpad_linux.cc')
-rw-r--r--chrome/app/breakpad_linux.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/app/breakpad_linux.cc b/chrome/app/breakpad_linux.cc
index 15d6e65..e471e55 100644
--- a/chrome/app/breakpad_linux.cc
+++ b/chrome/app/breakpad_linux.cc
@@ -646,7 +646,7 @@ void EnableCrashDumping(const bool unattended) {
}
}
// Currently Non-Browser = Renderer, Plugins and Native Client
static bool
NonBrowserCrashHandler(const void* crash_context, size_t crash_context_size,
void* context) {
@@ -748,7 +748,8 @@ void InitCrashReporter() {
} else if (process_type == switches::kRendererProcess ||
process_type == switches::kPluginProcess ||
process_type == switches::kZygoteProcess ||
- process_type == switches::kNaClLoaderProcess) {
+ process_type == switches::kNaClLoaderProcess ||
+ process_type == switches::kGpuProcess) {
// We might be chrooted in a zygote or renderer process so we cannot call
// GetCollectStatsConsent because that needs access the the user's home
// dir. Instead, we set a command line flag for these processes.
@@ -646,7 +646,7 @@ void EnableCrashDumping(const bool unattended) {
}
}
-// Currently Non-Browser = Renderer, Plugins and Native Client
+// Currently Non-Browser = Renderer, Plugins, Native Client and Gpu
static bool
NonBrowserCrashHandler(const void* crash_context, size_t crash_context_size,